@@ -4,6 +4,7 @@ import os
 
 import torch
 from torch import nn
+from torch._C import device
 from torch.nn import CrossEntropyLoss, MSELoss
 
 def swish(x):
@@ -464,7 +465,7 @@ class BertModel(BertPreTrainedModel):
             extended_attention_mask = attention_mask * extended_attention_mask
 
         if token_type_ids is None:
-            token_type_ids = torch.zeros_like(input_ids)
+            token_type_ids = torch.zeros_like(input_ids, dtype=torch.long, device=input_ids.device)
 
         # extended_attention_mask = extended_attention_mask.to(dtype=next(self.parameters()).dtype)  # fp16 compatibility
         extended_attention_mask = (1.0 - extended_attention_mask) * -10000.0
