@@ -46,12 +46,7 @@ class Seq2SeqModel(BasicBert):
     """
     """
     def __init__(self, word2ix, model_name="roberta", tokenizer=None):
-        super(Seq2SeqModel, self).__init__(word2ix=word2ix, model_name=model_name)
-        self.word2ix = word2ix
-        if tokenizer is None:
-            self.tokenizer = Tokenizer(word2ix)
-        else:
-            self.tokenizer = tokenizer
+        super(Seq2SeqModel, self).__init__(word2ix=word2ix, model_name=model_name, tokenizer=tokenizer)
             
         self.hidden_dim = self.config.hidden_size
         self.vocab_size = len(word2ix)
